﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Net.Http.Formatting;

namespace ProductStoreClient
{
    class Program
    {
        static void Main(string[] args)
        {
            HttpClient client = new HttpClient();
            client.BaseAddress = new Uri("http://localhost:38856/");

            // Add an Accept header for JSON format
            client.DefaultRequestHeaders.Accept.Add(new MediaTypeWithQualityHeaderValue("application/json"));

            //----------------------------------------------------------------------------------------------
            // List all products
            HttpResponseMessage response = client.GetAsync("api/products").Result;
            if (response.IsSuccessStatusCode)
            {
                var products = response.Content.ReadAsAsync<IEnumerable<Product>>().Result;
                foreach (var p in products)
                {
                    Console.WriteLine("{0}\t{1};\t{2}", p.Name, p.Price, p.Category);
                }
            }
                else
                {
                    Console.WriteLine("{0} ({1})", (int)response.StatusCode, response.ReasonPhrase);
                }

            //--------------------------------------------------------------------------------------------------
            // Get a product by ID
            response = client.GetAsync("api/products/1").Result;
            if (response.IsSuccessStatusCode)
            {
                // Parse the response body. Blocking!
                var product = response.Content.ReadAsAsync<Product>().Result;
                Console.WriteLine("{0}\t{1};\t{2}", product.Name, product.Price, product.Category);
            }
            else
            {
                Console.WriteLine("{0} ({1})", (int)response.StatusCode, response.ReasonPhrase);
            }

            //-------------------------------------------------------------------------------------------------------
            // Create a new product
            var gizmo = new Product() { Name = "Gizmo", Price = 100, Category = "Widget" };
            Uri gizmoUri = null;

            response = client.PostAsJsonAsync("api/products", gizmo).Result;
            if (response.IsSuccessStatusCode)
            {
                gizmoUri = response.Headers.Location;
            }
            else
            {
                Console.WriteLine("{0} ({1})", (int)response.StatusCode, response.ReasonPhrase);
            }

            //--------------------------------------------------------------------------------------------------------------
           // Create a new product in json format
            var productj = new Product() { Name = "Gizmo", Price = 100, Category = "Widget" };
             
            // Create the JSON formatter.
            MediaTypeFormatter jsonFormatter = new JsonMediaTypeFormatter();

            // Use the JSON formatter to create the content of the request body.
            HttpContent content = new ObjectContent<Product>(productj, jsonFormatter);

            // Send the request.
            var resp = client.PostAsync("api/products", content).Result;

            //--------------------------------------------------------------------------------------------------------------
            // Update a product
            gizmo.Price = 99.9;
            response = client.PutAsJsonAsync(gizmoUri.PathAndQuery, gizmo).Result;
            Console.WriteLine("{0} ({1})", (int)response.StatusCode, response.ReasonPhrase);

            //--------------------------------------------------------------------------------------------------------------
            // Delete a product
            response = client.DeleteAsync(gizmoUri).Result;
            Console.WriteLine("{0} ({1})", (int)response.StatusCode, response.ReasonPhrase);

            Console.ReadKey();
            }

    
        }

    }

    class Product
    {
        public string Name { get; set; }
        public double Price { get; set; }
        public string Category { get; set; }
    }



